# SG-NLP

Machine learning models from Singapore's natural language processing (NLP) research community.

`sgnlp` is a Python package that allows you to easily get started on using various (NLP) models implemented using the
Pytorch and Transfromers frameworks.

We have an accompanying [demo site](https://sgnlp.aisingapore.net/) where you can interact with our models and get a
better understanding on how they work.

## Installation

* Python >= 3.8

```
pip install sgnlp
```

## Documentation

Visit our [documentation](https://sgnlp.aisingapore.net/docs/) for tutorials.

## License

Code and models from this project are released under the MIT License unless otherwise stated. If a model's code is under
a separate license, it can be found in the respective model's folder.
